@@ -21,8 +21,29 @@ import _locale
 
 #see parameters available for date_preset here https://developers.facebook.com/docs/marketing-api/insights/parameters/
 
+
+
+"""
+MANDATORY INPUT: my_app_id, my_app_secret, my_access_token
+
+OPTIONAL:
+
+- date_preset: report days range.  
+               Optional, by default "last_7d".
+               See https://developers.facebook.com/docs/marketing-api/insights/parameters/ for date_preset available.
+
+
+- account_name: dictionary with name and id. 
+                Optional, by default it gets 'Humable','Linkers','WinWay', 'Miss Tariffa Agency','Numbers', 'We are Fiber', 'Miss Tariffa'
+
+"""
+
+
+
 def get_fb_ads(my_app_id, my_app_secret, my_access_token, 
-               date_preset = "today",
+               
+               #optional input below
+               date_preset = "last_7d",
                account_name = {'Numbers' : 'act_113103090066338',
                 'Linkers' : 'act_203938767415072',
                 'WinWay' : 'act_2591302164494270',
